## Quantifying the relationship between Munsell value and soil carbon

library(ggplot2)
library(dplyr)

ColorCarbon <- read.csv("~/_MovedData/R Project Directory/Soil Color Soil Properties/ColorCarbon.csv")

ColorCarbon$Value <- as.character(ColorCarbon$Value)
ColorCarbon$TotalCarbon <- ColorCarbon$Percent_Carbon*10
ColorCarbon$Value[ColorCarbon$Value=="5G"]<- NA
ColorCarbon$Value[ColorCarbon$Value==""]<- NA
ColorCarbon$Value[ColorCarbon$Value=="---"]<- NA
ColorCarbon$Value <- as.numeric(ColorCarbon$Value)
ColorCarbon36 <- filter(ColorCarbon$Value==3:6)
ColorCarbon2.8 <- filter(ColorCarbon, Value==c(2,2.5,7,8))


ColorCarbon36$Value <- as.numeric(ColorCarbon36$Value)
ColorCarbon2.8$Value <- as.numeric(ColorCarbon2.8$Value)
Model3 <- lm(log(TotalCarbon) ~ Value, data=ColorCarbon36, na.action=na.omit)
summary(Model3)

##Graph model results
#Value
preddat <- with(ColorCarbon36, data.frame(Value=seq(min(2),max(8),length=50)))

# Create predicted probabilities and 95% confidence intervals
preds <- cbind(preddat,
               predict(Model3,
                       data.frame(Value=seq(min(2),max(8),length=50)),
                       interval="confidence",
                       level=0.95)
)


# Create the plot

Value.Plot <- ggplot(preds, aes(x = Value, y = fit)) +
  geom_ribbon(aes(ymin = lwr,
                  ymax = upr),
              alpha = 1/5) +
  geom_line() +
  labs(x="Munsell Value", y="Total Carbon (g/kg soil)")+
  theme(legend.position="none")+
  theme_bw()+
  scale_y_continuous(limits=c(-1,4.5),
                  breaks=c(0,2.302585,3.401197, 3.912023,4.60517),
                 labels=c("1","10","30","50","100"))+
  scale_x_continuous(limits=c(2,8),
                     breaks=c(2,3,4,5,6,7,8),
                    labels=c("2","3","4","5","6","7","8")) +
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=14))+
  geom_point(data=ColorCarbon36,
             aes(x=Value,y=log(TotalCarbon)))+
  geom_point(data=ColorCarbon28,
             aes(x=Value,y=log(TotalCarbon)),
             shape=1)

tiff("Value2Carbon.tif", res=300, compression = "lzw", height=4, width=6, units="in")
Value.Plot
dev.off()


