library(ggplot2)
library(dplyr)
library(tidyr)
library(broom)
library(mgcv)
library(grid)
library(lattice)
library(Matrix)
library(ggthemes)

c.d <- read.csv#(Carbon_Slabbed.csv)





c.dsets <- split(c.d, c.d$city)




# after looking at data we should use generalized additive models (gams)
# you can add simple random effects to these right out of the box (see below) and they fit
# smoothed curves to data that change locally, as yours seem to. (you can do more complex stuff
# with gamm, too but unless you want to fit something across all cities you dont' need to get into that.
# GAMs are the smooth that ggplot2 usuualy fits if there are > 1000 data points
# so they're what produced the smooths in the plots i made above.


## Atlanta carbon model and plot
d.Atlanta.C <- c.dsets[[1]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Atlanta.C <- mgcv::gam(carbon ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                          data=d.Atlanta.C, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Atlanta.C,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Atlanta.C)

# implications
summary(m.Atlanta.C)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Atlanta.C <- broom::augment(m.Atlanta.C)
ggplot(p.Atlanta.C) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Atlanta.C <- expand.grid(type=unique(d.Atlanta.C$type),
                            top=seq(min(d.Atlanta.C$top),
                                    max(d.Atlanta.C$top),
                                    length.out=100))
f.Atlanta.C.p <- predict(m.Atlanta.C, newdata=f.Atlanta.C, exclude="s(id)",
                          newdata.guaranteed=TRUE, se.fit=TRUE)
f.Atlanta.C$.fitted_wo_re <- f.Atlanta.C.p$fit
f.Atlanta.C$.se <- f.Atlanta.C.p$se.fit

Atlanta.Carbon <- ggplot(f.Atlanta.C) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Atlanta") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Carbon (g/kg soil)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(0,50),
                     breaks=c(0,10,20,30,40,50))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Atlanta.C,file="Atlanta_f_C.csv",col.names=T, sep=",")


## Camden carbon model and plot
d.Camden.C <- c.dsets[[2]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Camden.C <- mgcv::gam(carbon ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                         data=d.Camden.C, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Camden.C,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Camden.C)

# implications
summary(m.Camden.C)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Camden.C <- broom::augment(m.Camden.C)
ggplot(p.Camden.C) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Camden.C <- expand.grid(type=unique(d.Camden.C$type),
                           top=seq(min(d.Camden.C$top),
                                   max(d.Camden.C$top),
                                   length.out=100))
f.Camden.C.p <- predict(m.Camden.C, newdata=f.Camden.C, exclude="s(id)",
                         newdata.guaranteed=TRUE, se.fit=TRUE)
f.Camden.C$.fitted_wo_re <- f.Camden.C.p$fit
f.Camden.C$.se <- f.Camden.C.p$se.fit

Camden.Carbon <- ggplot(f.Camden.C) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Camden") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Carbon (g/kg soil)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(0,50),
                     breaks=c(0,10,20,30,40,50))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Camden.C,file="Camden_f_C.csv",col.names=T, sep=",")

## Cincinnati carbon model and plot
d.Cincinnati.C <- c.dsets[[3]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Cincinnati.C <- mgcv::gam(carbon ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                             data=d.Cincinnati.C, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Cincinnati.C,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Cincinnati.C)

# implications
summary(m.Cincinnati.C)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Cincinnati.C <- broom::augment(m.Cincinnati.C)
ggplot(p.Cincinnati.C) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Cincinnati.C <- expand.grid(type=unique(d.Cincinnati.C$type),
                               top=seq(min(d.Cincinnati.C$top),
                                       max(d.Cincinnati.C$top),
                                       length.out=100))
f.Cincinnati.C.p <- predict(m.Cincinnati.C, newdata=f.Cincinnati.C, exclude="s(id)",
                             newdata.guaranteed=TRUE, se.fit=TRUE)
f.Cincinnati.C$.fitted_wo_re <- f.Cincinnati.C.p$fit
f.Cincinnati.C$.se <- f.Cincinnati.C.p$se.fit

Cincinnati.Carbon <- ggplot(f.Cincinnati.C) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Cincinnati") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Carbon (g/kg soil)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(0,50),
                     breaks=c(0,10,20,30,40,50))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Cincinnati.C,file="Cincinnati_f_C.csv",col.names=T, sep=",")


## Cleveland carbon model and plot
d.Cleveland.C <- c.dsets[[4]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Cleveland.C <- mgcv::gam(carbon ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                            data=d.Cleveland.C, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Cleveland.C,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Cleveland.C)

# implications
summary(m.Cleveland.C)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Cleveland.C <- broom::augment(m.Cleveland.C)
ggplot(p.Cleveland.C) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Cleveland.C <- expand.grid(type=unique(d.Cleveland.C$type),
                              top=seq(min(d.Cleveland.C$top),
                                      max(d.Cleveland.C$top),
                                      length.out=100))
f.Cleveland.C.p <- predict(m.Cleveland.C, newdata=f.Cleveland.C, exclude="s(id)",
                            newdata.guaranteed=TRUE, se.fit=TRUE)
f.Cleveland.C$.fitted_wo_re <- f.Cleveland.C.p$fit
f.Cleveland.C$.se <- f.Cleveland.C.p$se.fit

Cleveland.Carbon <- ggplot(f.Cleveland.C) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Cleveland") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Carbon (g/kg soil)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(0,50),
                     breaks=c(0,10,20,30,40,50))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Cleveland.C,file="Cleveland_f_C.csv",col.names=T, sep=",")


## Detroit carbon model and plot
d.Detroit.C <- c.dsets[[5]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Detroit.C <- mgcv::gam(carbon ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                          data=d.Detroit.C, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Detroit.C,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Detroit.C)

# implications
summary(m.Detroit.C)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Detroit.C <- broom::augment(m.Detroit.C)
ggplot(p.Detroit.C) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Detroit.C <- expand.grid(type=unique(d.Detroit.C$type),
                            top=seq(min(d.Detroit.C$top),
                                    max(d.Detroit.C$top),
                                    length.out=100))
f.Detroit.C.p <- predict(m.Detroit.C, newdata=f.Detroit.C, exclude="s(id)",
                          newdata.guaranteed=TRUE, se.fit=TRUE)
f.Detroit.C$.fitted_wo_re <- f.Detroit.C.p$fit
f.Detroit.C$.se <- f.Detroit.C.p$se.fit

Detroit.Carbon <- ggplot(f.Detroit.C) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Detroit") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Carbon (g/kg soil)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(0,50),
                     breaks=c(0,10,20,30,40,50))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Detroit.C,file="Detroit_f_C.csv",col.names=T, sep=",")


## New Orleans carbon model and plot
d.NewOrleans.C <- c.dsets[[6]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.NewOrleans.C <- mgcv::gam(carbon ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                             data=d.NewOrleans.C, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.NewOrleans.C,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.NewOrleans.C)

# implications
summary(m.NewOrleans.C)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.NewOrleans.C <- broom::augment(m.NewOrleans.C)
ggplot(p.NewOrleans.C) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.NewOrleans.C <- expand.grid(type=unique(d.NewOrleans.C$type),
                               top=seq(min(d.NewOrleans.C$top),
                                       max(d.NewOrleans.C$top),
                                       length.out=100))
f.NewOrleans.C.p <- predict(m.NewOrleans.C, newdata=f.NewOrleans.C, exclude="s(id)",
                             newdata.guaranteed=TRUE, se.fit=TRUE)
f.NewOrleans.C$.fitted_wo_re <- f.NewOrleans.C.p$fit
f.NewOrleans.C$.se <- f.NewOrleans.C.p$se.fit

NewOrleans.Carbon <- ggplot(f.NewOrleans.C) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("New Orleans") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Carbon (g/kg soil)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(0,50),
                     breaks=c(0,10,20,30,40,50))+
  scale_color_manual(values=c("red","blue"))

write.table(f.NewOrleans.C,file="NewOrleans_f_C.csv",col.names=T, sep=",")


## Omaha carbon model and plot
d.Omaha.C <- c.dsets[[7]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Omaha.C <- mgcv::gam(carbon ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                        data=d.Omaha.C, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Omaha.C,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Omaha.C)

# implications
summary(m.Omaha.C)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Omaha.C <- broom::augment(m.Omaha.C)
ggplot(p.Omaha.C) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Omaha.C <- expand.grid(type=unique(d.Omaha.C$type),
                          top=seq(min(d.Omaha.C$top),
                                  max(d.Omaha.C$top),
                                  length.out=100))
f.Omaha.C.p <- predict(m.Omaha.C, newdata=f.Omaha.C, exclude="s(id)",
                        newdata.guaranteed=TRUE, se.fit=TRUE)
f.Omaha.C$.fitted_wo_re <- f.Omaha.C.p$fit
f.Omaha.C$.se <- f.Omaha.C.p$se.fit

Omaha.Carbon <- ggplot(f.Omaha.C) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Omaha") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Carbon (g/kg soil)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(0,50),
                     breaks=c(0,10,20,30,40,50))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Omaha.C,file="Omaha_f_C.csv",col.names=T, sep=",")


## Phoenix carbon model and plot
d.Phoenix.C <- c.dsets[[8]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Phoenix.C <- mgcv::gam(carbon ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                          data=d.Phoenix.C, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Phoenix.C,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Phoenix.C)

# implications
summary(m.Phoenix.C)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Phoenix.C <- broom::augment(m.Phoenix.C)
ggplot(p.Phoenix.C) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Phoenix.C <- expand.grid(type=unique(d.Phoenix.C$type),
                            top=seq(min(d.Phoenix.C$top),
                                    max(d.Phoenix.C$top),
                                    length.out=100))
f.Phoenix.C.p <- predict(m.Phoenix.C, newdata=f.Phoenix.C, exclude="s(id)",
                          newdata.guaranteed=TRUE, se.fit=TRUE)
f.Phoenix.C$.fitted_wo_re <- f.Phoenix.C.p$fit
f.Phoenix.C$.se <- f.Phoenix.C.p$se.fit

Phoenix.Carbon <- ggplot(f.Phoenix.C) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Phoenix") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Carbon (g/kg soil)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(0,50),
                     breaks=c(0,10,20,30,40,50))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Phoenix.C,file="Phoenix_f_C.csv",col.names=T, sep=",")


## Portland carbon model and plot
d.Portland.C <- c.dsets[[9]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Portland.C <- mgcv::gam(carbon ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                           data=d.Portland.C, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Portland.C,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Portland.C)

# implications
summary(m.Portland.C)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Portland.C <- broom::augment(m.Portland.C)
ggplot(p.Portland.C) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Portland.C <- expand.grid(type=unique(d.Portland.C$type),
                             top=seq(min(d.Portland.C$top),
                                     max(d.Portland.C$top),
                                     length.out=100))
f.Portland.C.p <- predict(m.Portland.C, newdata=f.Portland.C, exclude="s(id)",
                           newdata.guaranteed=TRUE, se.fit=TRUE)
f.Portland.C$.fitted_wo_re <- f.Portland.C.p$fit
f.Portland.C$.se <- f.Portland.C.p$se.fit

Portland.Carbon <- ggplot(f.Portland.C) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Portland") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Carbon (g/kg soil)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(0,50),
                     breaks=c(0,10,20,30,40,50))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Portland.C,file="Portland_f_C.csv",col.names=T, sep=",")


## San Juan carbon model and plot
d.SanJuan.C <- c.dsets[[10]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.SanJuan.C <- mgcv::gam(carbon ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                          data=d.SanJuan.C, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.SanJuan.C,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.SanJuan.C)

# implications
summary(m.SanJuan.C)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.SanJuan.C <- broom::augment(m.SanJuan.C)
ggplot(p.SanJuan.C) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.SanJuan.C <- expand.grid(type=unique(d.SanJuan.C$type),
                            top=seq(min(d.SanJuan.C$top),
                                    max(d.SanJuan.C$top),
                                    length.out=100))
f.SanJuan.C.p <- predict(m.SanJuan.C, newdata=f.SanJuan.C, exclude="s(id)",
                          newdata.guaranteed=TRUE, se.fit=TRUE)
f.SanJuan.C$.fitted_wo_re <- f.SanJuan.C.p$fit
f.SanJuan.C$.se <- f.SanJuan.C.p$se.fit

SanJuan.Carbon <- ggplot(f.SanJuan.C) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("San Juan") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Carbon (g/kg soil)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(0,50),
                     breaks=c(0,10,20,30,40,50))+
  scale_color_manual(values=c("red","blue"))

write.table(f.SanJuan.C,file="SanJuan_f_C.csv",col.names=T, sep=",")


## Tacoma carbon model and plot
d.Tacoma.C <- c.dsets[[11]]
#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Tacoma.C <- mgcv::gam(carbon ~ type + s(top, by=type, bs="tp") + s(id, bs="re"),
                         data=d.Tacoma.C, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Tacoma.C,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Tacoma.C)

# implications
summary(m.Tacoma.C)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Tacoma.C <- broom::augment(m.Tacoma.C)
ggplot(p.Tacoma.C) + geom_boxplot(aes(id, .resid))

# look at predicted urban and rural profiles
f.Tacoma.C <- expand.grid(type=unique(d.Tacoma.C$type),
                           top=seq(min(d.Tacoma.C$top),
                                   max(d.Tacoma.C$top),
                                   length.out=100))
f.Tacoma.C.p <- predict(m.Tacoma.C, newdata=f.Tacoma.C, exclude="s(id)",
                         newdata.guaranteed=TRUE, se.fit=TRUE)
f.Tacoma.C$.fitted_wo_re <- f.Tacoma.C.p$fit
f.Tacoma.C$.se <- f.Tacoma.C.p$se.fit

Tacoma.Carbon <- ggplot(f.Tacoma.C) +
  geom_line(aes(top, .fitted_wo_re, color=type), size=1, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re + 2 * .se, color=type), linetype=2, show.legend=F) +
  geom_line(aes(top, .fitted_wo_re - 2 * .se, color=type), linetype=2, show.legend=F) +
  ggtitle("Tacoma") +
  scale_x_reverse(lim=c(150,0)) +
  coord_flip()+
  labs(y="Carbon (g/kg soil)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(0,50),
                     breaks=c(0,10,20,30,40,50))+
  scale_color_manual(values=c("red","blue"))

write.table(f.Tacoma.C,file="Tacoma_f_C.csv",col.names=T, sep=",")


## Combine all cities' model output for the global analysis
f.Atlanta.C$city <- "Atlanta"
f.Camden.C$city <- "Camden"
f.Cincinnati.C$city <- "Cincinnati"
f.Cleveland.C$city <- "Cleveland"
f.Detroit.C$city <- "Detroit"
f.NewOrleans.C$city <- "New Orleans"
f.Omaha.C$city <- "Omaha"
f.Phoenix.C$city <- "Phoenix"
f.Portland.C$city <- "Portland"
f.SanJuan.C$city <- "San Juan"
f.Tacoma.C$city <- "Tacoma"

d.Global.C <- bind_rows(f.Atlanta.C,f.Camden.C,f.Cincinnati.C,
                         f.Cleveland.C,f.Detroit.C,f.NewOrleans.C,
                         f.Omaha.C,f.Phoenix.C,f.Portland.C,
                         f.SanJuan.C,f.Tacoma.C)

d.Global.C$carbon <- d.Global.C$.fitted_wo_re

d.Global.C$city <- as.factor(d.Global.C$city)
d.Global.C$top <- as.numeric(d.Global.C$top)
d.Global.C$type <- as.factor(d.Global.C$type)
d.Global.C$carbon <- as.numeric(d.Global.C$carbon)
# 
# d.Global.C <- read.csv("//aa.ad.epa.gov/ORD/CIN/USERS/MAIN/A-E/dherrman/Net MyDocuments/_MovedData/R Project Directory/Convergence/Global_d_C.csv")

#use REML so we can do AIC; thin plate spline 'tp' is deault but spelled ou here
# the id=TRUE arugment makes the smooths the same on each level of type which i
# think is more conservative?
# the smooth on id, with 're', is equivlanet ot random effect model
# see help('random.effects')
m.Global.C <- mgcv::gam(carbon ~ type + s(top, by=type, bs="tp") + s(city, bs="re"),
                         data=d.Global.C, method="REML")


# standard plots
op <- par(mfrow=c(2,2))
## use alternative plotting scheme so intervals include smoothing parameter
## uncertainty...
plot(m.Global.C,pages=1,scheme=1,unconditional=TRUE) 
par(op)

#standard diagnostics form package
gam.check(m.Global.C)

# implications
summary(m.Global.C)
# see help('summary.gam') for how p vals computed

# look at fit in ggplot
p.Global.C <- broom::augment(m.Global.C)
ggplot(p.Global.C) + geom_boxplot(aes(city, .resid))

# look at predicted urban and rural profiles
f.Global.C <- expand.grid(type=unique(d.Global.C$type),
                           top=seq(min(d.Global.C$top),
                                   max(d.Global.C$top),
                                   length.out=100))
f.Global.C.p <- predict(m.Global.C, newdata=f.Global.C, exclude="s(city)",
                         newdata.guaranteed=TRUE, se.fit=TRUE)
f.Global.C$.fitted_wo_re <- f.Global.C.p$fit
f.Global.C$.se <- f.Global.C.p$se.fit

Global.Carbon <- ggplot(f.Global.C, aes(top, .fitted_wo_re, fill=type, color=type)) +
  geom_ribbon(aes(ymin = .fitted_wo_re - 2 * .se,
                  ymax = .fitted_wo_re + 2 * .se),
              alpha = 1/3, color=NA, show.legend=F)+
  geom_line(size=1, show.legend=F) +
  scale_x_reverse(lim=c(150,-5)) +
  theme_bw()+
  coord_flip()+
  labs(y="Carbon (g/kg soil)", x="Depth (cm)")+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 10),
        text=element_text(size=10, colour="black"),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"),
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 10))+
  scale_y_continuous(limits=c(0,42),
                     breaks=c(0,10,20,30,40))+
  scale_color_manual(values=c("red","blue"))+
  scale_fill_manual(values=c("red","blue"))+
  geom_line(data=f.Atlanta.C, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Camden.C, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Cincinnati.C, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Cleveland.C, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Detroit.C, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.NewOrleans.C, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Omaha.C, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Phoenix.C, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Portland.C, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.SanJuan.C, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_line(data=f.Tacoma.C, aes(top, .fitted_wo_re, color=type), alpha=1/6, size=0.5, show.legend=F)+
  geom_text(x=5, y=18, label="Urban", color="blue", size=3)+
  geom_text(x=5, y=27, label="Reference", color="red", size=3)

tiff("GRL_Figure_Global Carbon profile.tif", res=1000, compression = "lzw", height=4.56, width=3.42, units="in")
Global.Carbon
dev.off()

## Get model summaries
summary(m.Global.C)
summary(m.Atlanta.C)
summary(m.Camden.C)
summary(m.Cincinnati.C)
summary(m.Cleveland.C)
summary(m.Detroit.C)
summary(m.NewOrleans.C)
summary(m.Omaha.C)
summary(m.Phoenix.C)
summary(m.Portland.C)
summary(m.SanJuan.C)
summary(m.Tacoma.C)



