## Index of Profie Anisotropy after Walker and other name 1976

library(dplyr)

h <- read.csv("~/_MovedData/R Project Directory/Convergence/Carbon_Slabbed.csv")

#Get mean value by profile

max_depth <- h %>%
  group_by(id) %>%
  summarise(max_depth = max(bottom))

mean_c <- h %>%
  group_by(id) %>%
  summarise(mean_carbon = mean(carbon))

h <- left_join(h, mean_c, by = "id")
h <- left_join(h, max_depth, by = "id")

#Remove rows with max_depth not 150
h <- filter(h, max_depth==150)

#Calculate Index of Profile Anisotropy (IPA) by id

h$deviance_c <- abs(h$mean_c - h$carbon)

sum_dev <- h %>%
  group_by(id) %>%
  summarise(IPA = sum(deviance_c))

h <- left_join(h, sum_dev, by = "id")

h$IPA <- h$sum_dev/h$mean_c

i <- filter(h, top==1)

#Join soil series column and align urban with their reference values in rows

series <- read.csv("~/_MovedData/R Project Directory/Convergence/series.csv")

i <- left_join(i, series, by="id")

j <- filter(i, type=="urban")
j <- select(j, id, city, order, mean_carbon, deviance_c, IPA, Reference_Series)
k <- filter(i, type=="reference")
write.csv(k, file = "k.csv")
#Separate id column to get series column in excel and reimport
k <- read.csv("~/_MovedData/R Project Directory/Convergence/k.csv")
k <- select(k, series, mean_carbon, deviance_c, IPA)
names(j) <- c("id", "city","order", "mean_carbon_urban", "deviance_c_urban", "IPA_urban", "series")
names(k) <- c("series", "mean_carbon_ref", "deviance_c_ref", "IPA_ref")
j <- left_join(j,k, by="series")

#Remove IPAs of below detection limit carbon profiles (in this case, where value is uniform across whole profile)
j <- filter(j, deviance_c_ref>0)
j <- filter(j, deviance_c_urban>0)

# Create relative IPA (change in urban IPA relative to reference IPA)

j$rIPA <- (j$IPA_urban)/(j$IPA_ref)
j$log_IPA_ref <- log(j$IPA_ref)
j$log_rIPA <- log(j$rIPA)

# plot(log(f$IPA_ref), log(f$rIPA),
#      #ylim=c(-3,3),
#      #xlim=c(0,8),
#      col=f$city)+
#   abline(0,0, lty=2)+
#   abline(lm(log(f$rIPA)~(log(f$IPA_ref))), col="red")


#Build the model
m1 <- lm(log_rIPA~log_IPA_ref, j)
summary(m1)
plot(fitted(m1),residuals(m1))
#a <- curve(685.1495/x, from=127.7, to=3055, n=500)
#a <- data.frame(a)
#Build the ggplot

preddat.C <- with(j, data.frame(log_IPA_ref=seq(min(4.850),max(8.025),length=150)))

# Create predicted probabilities and 95% confidence intervals
preds.C <- cbind(preddat.C,
               predict(m1,
                       data.frame(log_IPA_ref=seq(min(4.850),max(8.025),length=150)),
                       interval="confidence",
                       level=0.95)
)


# Create the plot

Carbon.IPA.plot <- ggplot(preds.C, aes(x = log_IPA_ref, y = fit)) +
  geom_ribbon(aes(ymin = lwr,
                  ymax = upr),
              alpha = 1/3) +
  geom_line() +
  labs(y="", x="")+
  #theme(legend.position="none")+
  theme_bw()+
  scale_y_continuous(limits=c(-3,3),
                     breaks=c(-4.60517,-2.302585,0,2.302585,4.60517),
                     labels=c(expression(10^-2),expression(10^-1),expression(10^0),expression(10^1),expression(10^2))) +
  scale_x_continuous(limits=c(4.6,8.1),
                     breaks=c(-2.302585,0,2.302585,4.60517,6.907755),
                     labels=c(expression(10^-1),expression(10^0),expression(10^1),expression(10^2),expression(10^3))) +
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 16),
        text=element_text(size=16),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"), 
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 16))+
  geom_point(data=j,
            aes(x=log(IPA_ref),y=log(rIPA)),
            alpha = 1,
            shape = 1,
            size=3,
            show.legend = F)+
  geom_hline(yintercept=0, linetype=2)
  #geom_hline(yintercept=c(-2.302585,-0.6931472,0.6931472,2.302585),alpha=1/5)+
  #geom_line(data=a, aes(x=log(x), y=log(y)), color="gold", size=2,linetype=2)


tiff("Carbon_IPA.tif", res=300, compression = "lzw", height=5, width=7, units="in")
Carbon.IPA.plot
dev.off()

#Find the value of x in m0 where y=0
z <- 6.0404/0.9248
conv.line <- curve(z/x,4.5,8.5)

plot(f$IPA_ref, f$rIPA,
     #ylim=c(0,20),
     col=f$order)+
  abline(1,0, lty=2)

plot(f$IPA_ref, f$rIPA,
     ylim=c(0,20),
     col=f$order)+
  abline(1,0, lty=2)


plot(log(f$IPA_ref+1), log(f$IPA_urban+1),
     ylim=c(4,8),
     xlim=c(4,8),
     col=f$order)+
  abline(0,1, lty=2)+
  abline(lm(f$logIPAurban~f$logIPAref), col="red")

plot(f$IPA_ref, f$IPA_urban,
     #ylim=c(0,20),
     col=f$order)+
  abline(0,1, lty=2)

#Acquire city and soil order summary statistics

IPA_city <- e %>%
  group_by(city, type) %>%
  summarise(IPA_mean_city = mean(IPA, na.rm=TRUE),
            IPA_sd_city = sd(IPA, na.rm=TRUE),
            IPA_N_city = length(IPA))

IPA_order <- e %>%
  group_by(order, type) %>%
  summarise(IPA_mean_order = mean(IPA, na.rm=TRUE),
            IPA_sd_order = sd(IPA, na.rm=TRUE),
            IPA_N_order = length(IPA))

#Plot the results
library(ggplot2)

IPA_city_plot <- ggplot(IPA_city, aes(x=city,
                                               y=IPA_mean_city,
                                               ymin=IPA_mean_city-IPA_sd_city,
                                               ymax=IPA_mean_city+IPA_sd_city,
                                               fill=type)) +
  geom_bar(position=position_dodge(), aes(y=IPA_mean_city), stat="identity"
  )+
  geom_errorbar(position=position_dodge(width=0.9), colour="black", width=0.2)+
  labs(x="City", y="Index of Profile Anisotropy")+
  theme_bw()+
  scale_y_continuous(limits=c(0,100),
                     breaks=c(0,25,50,75,100))+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 12),
        text=element_text(size=12),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"), 
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 12),
        legend.position=c(0.8,0.8),
        legend.title=element_blank())

tiff("IPA_City_BarChart.tif", res=300, compression = "lzw", height=3, width=4, units="in")
IPA_city_plot
dev.off()

IPA_order_plot <- ggplot(IPA_order, aes(x=order,
                                      y=IPA_mean_order,
                                      ymin=IPA_mean_order-IPA_sd_order,
                                      ymax=IPA_mean_order+IPA_sd_order,
                                      fill=type)) +
  geom_bar(position=position_dodge(), aes(y=IPA_mean_order), stat="identity"
  )+
  geom_errorbar(position=position_dodge(width=0.9), colour="black", width=0.2)+
  labs(x="City", y="Index of Profile Anisotropy")+
  theme_bw()+
  scale_y_continuous(limits=c(0,100),
                     breaks=c(0,25,50,75,100))+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 12),
        text=element_text(size=12),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"), 
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 12),
        legend.position=c(0.8,0.8),
        legend.title=element_blank())

## Prep data for plot of IPA ref vs IPA urban

IPA_urban_city <- filter(IPA_city, type=="urban")
IPA_ref_city <- filter(IPA_city, type=="reference")
names(IPA_urban_city) <- c("city","type",	"IPA_mean_urban","IPA_sd_urban","IPA_N_urban")
names(IPA_ref_city) <- c("city","type",  "IPA_mean_ref","IPA_sd_ref","IPA_N_ref")
IPA_city_2 <-left_join(IPA_urban_city,IPA_ref_city, by="city")

plot(IPA_city_2$IPA_mean_ref, IPA_city_2$IPA_mean_urban,
     xlim=c(0,1500),
     ylim=c(0,1500))+
  abline(0,1,lty=2)+
  abline(lm(IPA_city_2$IPA_mean_urban~IPA_city_2$IPA_mean_ref), col="red")

IPA_urban_order <- filter(IPA_order, type=="urban")
IPA_ref_order <- filter(IPA_order, type=="reference")
names(IPA_urban_order) <- c("order","type",  "IPA_mean_urban","IPA_sd_urban","IPA_N_urban")
names(IPA_ref_order) <- c("order","type",  "IPA_mean_ref","IPA_sd_ref","IPA_N_ref")
IPA_order_2 <-left_join(IPA_urban_order,IPA_ref_order, by="order")

plot(IPA_order_2$IPA_mean_ref, IPA_order_2$IPA_mean_urban,
     xlim=c(0,2000),
     ylim=c(0,2000))+
  abline(0,1,lty=2)+
  abline(lm(IPA_order_2$IPA_mean_urban~IPA_order_2$IPA_mean_ref), col="red")

