## Index of Profie Anisotropy after Walker and other name 1976
## For Texture/Particle Size Diameter

library(dplyr)

d <- read.csv("~/_MovedData/R Project Directory/Convergence/Texture_Slabbed.csv")

#Derive geometric mean of particle size diameter following Schirazi and Boersma 1984 SSSAJ

d$sand <- as.numeric(d$sand)
d$clay <- as.numeric(d$clay)

d$silt <- 100-(d$sand+d$clay)
d$silt <- as.numeric(d$silt)
d$particle <- exp(0.01*((d$sand*log(1.025))+(d$silt*log(0.026))+(d$clay*log(0.001))))

#Export d as csv

write.csv(d, file = "d.csv")

#Get mean value by profile

max_depth <- d %>%
  group_by(id) %>%
  summarise(max_depth = max(bottom))

mean_particle <- d %>%
  group_by(id) %>%
  summarise(mean_particle = mean(particle))

d <- left_join(d, mean_particle, by = "id")
d <- left_join(d, max_depth, by = "id")

#Remove rows with max_depth not 150
d <- filter(d, max_depth==150)

#Calculate Index of Profile Anisotropy (IPA) by id

d$deviance_p <- abs(d$mean_particle - d$particle)

sum_dev <- d %>%
  group_by(id) %>%
  summarise(IPA = sum(deviance_p))

d <- left_join(d, sum_dev, by = "id")

d$IPA <- d$sum_dev/d$mean_particle

e <- filter(d, top==1)

#Join soil series column and align urban with their reference values in rows

series <- read.csv("~/_MovedData/R Project Directory/Convergence/series.csv")

e <- left_join(e, series, by="id")

f <- filter(e, type=="Urban")
f <- select(f, id, city, mean_particle, deviance_p, IPA, Reference_Series)
g <- filter(e, type=="Reference")
write.csv(g, file = "g.csv")
#Separate id column to get series column in excel and reimport
g <- read.csv("~/_MovedData/R Project Directory/Convergence/g.csv")
g <- select(g, series, mean_particle, deviance_p, IPA)
names(f) <- c("id", "city", "mean_particle_urban", "deviance_p_urban", "IPA_urban", "series")
names(g) <- c("series", "mean_particle_ref", "deviance_p_ref", "IPA_ref")
f <- left_join(f,g, by="series")

#Remove IPAs of below detection limit carbon profiles (in this case, where value is uniform across whole profile)
f <- filter(f, IPA_ref>0)
f <- filter(f, IPA_urban>0)

#visualize data

ggplot(f, aes(x=mean_particle_urban, y=mean_particle_ref))+
  geom_point()

ggplot(f, aes(x=log(IPA_ref), y=log(rIPA)))+
  geom_point()

# Create relative IPA (change in urban IPA relative to reference IPA)

f$rIPA <- (f$IPA_urban)/(f$IPA_ref)
f$log_IPA_ref <- log(f$IPA_ref)
f$log_rIPA <- log(f$rIPA)

plot(log(f$IPA_ref), log(f$rIPA),
     #ylim=c(-3,3),
     #xlim=c(0,8),
     col=f$city)+
  abline(0,0, lty=2)+
  abline(lm(log(f$rIPA)~(log(f$IPA_ref))),na.exclude, col="red")


#Build the pre logged model
m0 <- lm(log_rIPA~log_IPA_ref, f)
summary(m0)
plot(fitted(m0),residuals(m0))
a <- curve(1.273768/x, from=0.226, to=57.8, n=500)
a <- data.frame(a)
#Build the ggplot

preddat <- with(f, data.frame(log_IPA_ref=seq(min(-1.487),max(4.057),length=150)))

# Create predicted probabilities and 95% confidence intervals
preds <- cbind(preddat,
               predict(m0,
                       data.frame(log_IPA_ref=seq(min(-1.487),max(4.057),length=150)),
                       interval="confidence",
                       level=0.95)
)


# Create the plot

Part.IPA.plot <- ggplot(preds, aes(x = log_IPA_ref, y = fit)) +
  geom_ribbon(aes(ymin = lwr,
                  ymax = upr),
              alpha = 1/3) +
  geom_line() +
  labs(title="",
       y="",
       x="")+
  #theme(legend.position="none")+
  theme_bw()+
  scale_x_continuous(lim=c(-1.5,3.1),
                     breaks=c(-2.302585,0,2.302585,4.60517),
                     labels=c(expression(10^-1),expression(10^0),expression(10^1),expression(10^2))) +
  scale_y_continuous(lim=c(-7,3.3),
                     breaks=c(-4.60517,-2.302585,0,2.302585,4.60517),
                     labels=c(expression(10^-2),expression(10^-1),expression(10^0),expression(10^1),expression(10^2)))+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 16),
        text=element_text(size=16),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"), 
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 16))+
  geom_point(data=f,
             aes(x=log(IPA_ref),y=log(rIPA)),
             alpha = 1,
             shape = 1,
             size=3,
             show.legend = F)+
  geom_hline(yintercept=0, linetype=2)
  #geom_hline(yintercept=c(-2.302585,-0.6931472,0.6931472,2.302585),alpha=1/5)+
  #geom_line(data=a, aes(x=log(x), y=log(y)), color="gold", size=2,linetype=2)


tiff("Particle_IPA.tif", res=300, compression = "lzw", height=5, width=7, units="in")
Part.IPA.plot
dev.off()


##Plot raw data with depth

ggplot(d, aes(x=bottom, y=particle, color=city))+
  geom_point()




#Find the value of x in m0 where y=0
z <- 6.0404/0.9248
conv.line <- curve(z/x,4.5,8.5)

plot(f$IPA_ref, f$rIPA,
     #ylim=c(0,20),
     col=f$order)+
  abline(1,0, lty=2)

plot(f$IPA_ref, f$rIPA,
     ylim=c(0,20),
     col=f$order)+
  abline(1,0, lty=2)


plot(log(f$IPA_ref+1), log(f$IPA_urban+1),
     ylim=c(4,8),
     xlim=c(4,8),
     col=f$order)+
  abline(0,1, lty=2)+
  abline(lm(f$logIPAurban~f$logIPAref), col="red")

plot(f$IPA_ref, f$IPA_urban,
     #ylim=c(0,20),
     col=f$order)+
  abline(0,1, lty=2)

#Acquire city and soil order summary statistics

IPA_city <- e %>%
  group_by(city, type) %>%
  summarise(IPA_mean_city = mean(IPA, na.rm=TRUE),
            IPA_sd_city = sd(IPA, na.rm=TRUE),
            IPA_N_city = length(IPA))

IPA_order <- e %>%
  group_by(order, type) %>%
  summarise(IPA_mean_order = mean(IPA, na.rm=TRUE),
            IPA_sd_order = sd(IPA, na.rm=TRUE),
            IPA_N_order = length(IPA))

#Plot the results
library(ggplot2)

IPA_city_plot <- ggplot(IPA_city, aes(x=city,
                                      y=IPA_mean_city,
                                      ymin=IPA_mean_city-IPA_sd_city,
                                      ymax=IPA_mean_city+IPA_sd_city,
                                      fill=type)) +
  geom_bar(position=position_dodge(), aes(y=IPA_mean_city), stat="identity"
  )+
  geom_errorbar(position=position_dodge(width=0.9), colour="black", width=0.2)+
  labs(x="City", y="Index of Profile Anisotropy")+
  theme_bw()+
  scale_y_continuous(limits=c(0,100),
                     breaks=c(0,25,50,75,100))+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 12),
        text=element_text(size=12),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"), 
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 12),
        legend.position=c(0.8,0.8),
        legend.title=element_blank())

tiff("IPA_City_BarChart.tif", res=300, compression = "lzw", height=3, width=4, units="in")
IPA_city_plot
dev.off()

IPA_order_plot <- ggplot(IPA_order, aes(x=order,
                                        y=IPA_mean_order,
                                        ymin=IPA_mean_order-IPA_sd_order,
                                        ymax=IPA_mean_order+IPA_sd_order,
                                        fill=type)) +
  geom_bar(position=position_dodge(), aes(y=IPA_mean_order), stat="identity"
  )+
  geom_errorbar(position=position_dodge(width=0.9), colour="black", width=0.2)+
  labs(x="City", y="Index of Profile Anisotropy")+
  theme_bw()+
  scale_y_continuous(limits=c(0,100),
                     breaks=c(0,25,50,75,100))+
  theme(axis.line = element_line(colour = "black"),
        axis.text = element_text(size = 12),
        text=element_text(size=12),
        panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(), 
        title=element_text(color="black"), 
        axis.title=element_text(color="black"), 
        legend.text = element_text(size = 12),
        legend.position=c(0.8,0.8),
        legend.title=element_blank())

## Prep data for plot of IPA ref vs IPA urban

IPA_urban_city <- filter(IPA_city, type=="urban")
IPA_ref_city <- filter(IPA_city, type=="reference")
names(IPA_urban_city) <- c("city","type",  "IPA_mean_urban","IPA_sd_urban","IPA_N_urban")
names(IPA_ref_city) <- c("city","type",  "IPA_mean_ref","IPA_sd_ref","IPA_N_ref")
IPA_city_2 <-left_join(IPA_urban_city,IPA_ref_city, by="city")

plot(IPA_city_2$IPA_mean_ref, IPA_city_2$IPA_mean_urban,
     xlim=c(0,1500),
     ylim=c(0,1500))+
  abline(0,1,lty=2)+
  abline(lm(IPA_city_2$IPA_mean_urban~IPA_city_2$IPA_mean_ref), col="red")

IPA_urban_order <- filter(IPA_order, type=="urban")
IPA_ref_order <- filter(IPA_order, type=="reference")
names(IPA_urban_order) <- c("order","type",  "IPA_mean_urban","IPA_sd_urban","IPA_N_urban")
names(IPA_ref_order) <- c("order","type",  "IPA_mean_ref","IPA_sd_ref","IPA_N_ref")
IPA_order_2 <-left_join(IPA_urban_order,IPA_ref_order, by="order")

plot(IPA_order_2$IPA_mean_ref, IPA_order_2$IPA_mean_urban,
     xlim=c(0,2000),
     ylim=c(0,2000))+
  abline(0,1,lty=2)+
  abline(lm(IPA_order_2$IPA_mean_urban~IPA_order_2$IPA_mean_ref), col="red")
